Stan Math Library: stan/math/rev/scal/fun/ceil.hpp Source File

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

ceil.hpp
Go to the documentation of this file.
1 #ifndef STAN_MATH_REV_SCAL_FUN_CEIL_HPP
2 #define STAN_MATH_REV_SCAL_FUN_CEIL_HPP
3
4 #include <stan/math/rev/core.hpp>
5 #include <stan/math/prim/scal/meta/likely.hpp>
6 #include <boost/math/special_functions/fpclassify.hpp>
7 #include <cmath>
8 #include <limits>
9
10 namespace stan {
11 namespace math {
12
13 namespace {
14 class ceil_vari : public op_v_vari {
15 public:
16 explicit ceil_vari(vari* avi) :
17 op_v_vari(std::ceil(avi->val_), avi) {
18 }
19 void chain() {
20 if (unlikely(boost::math::isnan(avi_->val_)))
21 avi_->adj_ = std::numeric_limits<double>::quiet_NaN();
22 }
23 };
24 }
25
60 inline var ceil(const var& a) {
61 return var(new ceil_vari(a.vi_));
62 }
63
64 }
65 }
66 #endif
core.hpp
stan
Definition: log_sum_exp.hpp:8
std
Definition: std_numeric_limits.hpp:7
stan::math::var
Independent (input) and dependent (output) variables for gradients.
Definition: var.hpp:31
boost::math::isnan
bool isnan(const stan::math::var &v)
Checks if the given number is NaN.
Definition: boost_isnan.hpp:22
unlikely
#define unlikely(x)
Definition: likely.hpp:9
stan::math::var::vi_
vari * vi_
Pointer to the implementation of this variable.
Definition: var.hpp:43
likely.hpp
stan::math::ceil
fvar< T > ceil(const fvar< T > &x)
Definition: ceil.hpp:11

[ Stan Home Page ] © 2011–2016, Stan Development Team.